class Debug {
    static debuggingEnabled: bool;
    static log(str: string): void;
    static warn(str: string): void;
}
class KeyInput {
    private _pressed;
    static LEFT: number;
    static UP: number;
    static RIGHT: number;
    static DOWN: number;
    static CTRL: number;
    static SHIFT: number;
    static TAB: number;
    static W: number;
    static S: number;
    static A: number;
    static D: number;
    constructor ();
    public keyIsDown(keycode: number): bool;
    private onKeyDown(keycode);
    private onKeyUp(keycode);
}
class MathUtils {
    static degreesToRadians(degrees: number): number;
    static distanceBetween(point1: Point, point2: Point): number;
}
class Asset {
    public type: string;
    public url: string;
    public tag: string;
    public atlasData: AtlasFrameData[];
    public atlasDataRequest;
    public content;
}
class AtlasFrameData {
    public frameX: number;
    public frameY: number;
    public frameWidth: number;
    public frameHeight: number;
    public filename: string;
}
class Point {
    private xval;
    private yval;
    public x: number;
    public y: number;
    constructor (xval?: number, yval?: number);
    public distanceToPoint(point: Point): number;
}
class Rect {
    private _x;
    private _y;
    private _width;
    private _height;
    private _left;
    private _right;
    private _top;
    private _bottom;
    public x : number;
    public y : number;
    public width : number;
    public height : number;
    public left : number;
    public right : number;
    public top : number;
    public bottom : number;
    constructor (x: number, y: number, w: number, h: number);
    public containsPoint(point: Point): bool;
    public containsRect(rect: Rect): bool;
    public intersectsRect(rect: Rect): bool;
}
class ScreenData {
    private _width;
    private _height;
    private _canvas;
    public width : number;
    public height : number;
    public canvas : any;
    constructor (canvas: any, width: number, height: number);
    public setBackgroundImage(url: string, repeat?: bool): void;
}
class Component {
}
class Entity {
    private _tag;
    private _components;
    private _componentsCount;
    public components(): Component[];
    public componentsCount(): number;
    public tag(): string;
    constructor (tag: string);
    public componentAddWithTag(component: Component, tag: string): void;
    public componentGetWithTag(tag: string);
    public componentRemoveWithTag(tag: string): void;
    public onAddedToGame(): void;
    public onRemoveFromGame(): void;
}
class System {
    public tag: string;
    public nodelist: SystemNodeList;
    constructor ();
    public start(): void;
    public update(dt: number, t: number): void;
    public end(): void;
}
class SystemNode {
    public next;
    public previous;
    public entity;
    constructor (entity: Entity);
}
class SystemNodeList {
    public head;
    public tail;
    constructor ();
    public add(node): void;
    public remove(node): void;
    public removeAll(): void;
}
class Engine {
    public managerEntity: ManagerEntity;
    public managerSystem: ManagerSystem;
    public managerAsset: ManagerAsset;
    public managerNode: ManagerSystemNode;
    private _initialTime;
    private _deltaTime;
    private _timeElapsed;
    private _timeElapsedTotal;
    private _timeLast;
    private _timeScale;
    private _gameIsPaused;
    constructor (canvas, width, height);
    public setCoreRunning(val: bool): void;
    public main(scope): void;
}
class ComponentPosition extends Component {
    public x: number;
    public y: number;
    public rotation: number;
    public origin: Point;
}
class ComponentAnimation extends Component {
    private _frames;
    public currentFrame: AtlasFrameData;
    private _currentAnimationTag;
    public frameskip: number;
    public frameskipCounter: number;
    public frameCounter: number;
    private _frameAnimations;
    public frames : AtlasFrameData[];
    public currentAnimationTag : string;
    public addWithTag(tag: string, frames: string[]): void;
    public getWithTag(tag: string): string[];
}
class ComponentVelocity extends Component {
    public x: number;
    public y: number;
    public damping: number;
}
class ComponentDisplay extends Component {
    private _view;
    private _width;
    private _height;
    private _scaleX;
    private _scaleY;
    private _origWidth;
    private _origHeight;
    public view : any;
    public width : number;
    public height : number;
    public scaleX : number;
    public scaleY : number;
    public scale : Point;
}
class ManagerEntity {
    static instance: ManagerEntity;
    private _entities;
    private _entitiesCount;
    public entityCount(): number;
    constructor ();
    public getWithTag(tag: string): Entity;
    public addWithTag(entity: Entity, tag: string): void;
    public removeWithTag(tag: string): void;
}
class ManagerAsset {
    static instance: ManagerAsset;
    private _assets;
    private _queue;
    public preloading: bool;
    private _returnFunction;
    static TYPE_IMAGE: string;
    static TYPE_AUDIO: string;
    static TYPE_ATLAS: string;
    constructor ();
    public addWithTag(assetURL: string, type: string, tag: string): void;
    public queueLoad(notify: () => any): void;
    public getWithTag(tag: string);
    private preloadNextItem(scope);
}
class ManagerSystemNode {
    static instance: ManagerSystemNode;
    private _nodeList;
    constructor ();
    public addToList(node: SystemNode, type): void;
    public initList(type): void;
    public getList(type): SystemNodeList;
}
class ManagerSystem {
    static instance: ManagerSystem;
    private _systems_input;
    private _systems_update;
    private _systems_collision;
    private _systems_render;
    static PRIORITY_INPUT: string;
    static PRIORITY_UPDATE: string;
    static PRIORITY_COLLISION: string;
    static PRIORITY_RENDER: string;
    constructor ();
    public addWithTag(system: System, tag: string, priority: string): void;
    public getWithTag(tag: string): System;
    public update(dt: number, t: number): void;
    public removeWithTag(tag: string): void;
}
class SystemCanvasRenderer extends System {
    private _screenData;
    private _ctx;
    constructor (screenData: ScreenData);
    public start(): void;
    public update(dt: number, t: number): void;
    public end(): void;
}
class SystemMovement extends System {
    constructor ();
    public start(): void;
    public update(dt: number, t: number): void;
    public end(): void;
}
class SystemAnimation extends System {
    private _ctx;
    constructor ();
    public start(): void;
    public update(dt: number, t: number): void;
    public end(): void;
}
class SystemLogic extends System {
    constructor ();
    public start(): void;
    public update(dt: number, t: number): void;
    public end(): void;
}
class NodeMovement extends SystemNode {
    public velocity: ComponentVelocity;
    public position: ComponentPosition;
}
class NodeRenderable extends SystemNode {
    public display: ComponentDisplay;
    public position: ComponentPosition;
    public animation: ComponentAnimation;
}
class NodeAnimation extends SystemNode {
    public animation: ComponentAnimation;
    public display: ComponentDisplay;
}
class NodeLogic extends SystemNode {
    public position: ComponentPosition;
    public velocity: ComponentVelocity;
    public display: ComponentDisplay;
    public animation: ComponentAnimation;
}
class Sprite extends Entity {
    public position: ComponentPosition;
    public display: ComponentDisplay;
    public animation: ComponentAnimation;
    public velocity: ComponentVelocity;
    constructor (tag: string, img: string, atlas: bool);
}
